/**
 * Serve Atom feeds for comments on sites.
 */
import express from "express";
import { Feed } from "feed";

import utils from "./utils.mjs";
import db from "./db.mjs";

// Router

const router = express.Router();
export default router;
router.use(express.json());

const domain = utils.domain;

/**
 * Serve feed for all comments in a specific :site as XML Atom feed.
 */
router.get("/:site", utils.get_limiter, (req, res) => {
    const site = req.params.site;

    var feed = new Feed({
        title: "UCS",
        generator: "UCS",
        description: "תגובות עבור האתר " + site,
        id: domain + "/feed/" + site,
        link: domain,
        language: "he",
    });

    const comments = db.siteComments(site);

    for (const comment of comments) {
        feed.addItem({
            title: `New message by '${comment.user}' on ${comment.path}`,
            description: comment.message,
            id: `${comment.site}/${comment.path}#comment-${comment.id}`,
            link: `${comment.site}/${comment.path}#comment-${comment.id}`,
            date: new Date(comment.published),
        });
    }

    var xml = feed.atom1();

    res.set("Content-Type", "text/xml");
    res.send(xml);
});

/**
 * Serve feed comments in a specific :site and page as XML Atom feed.
 */
router.get("/:site/*", utils.get_limiter, (req, res) => {
    const site = req.params.site;
    const path = req.params[0];

    var feed = new Feed({
        title: "UCS",
        generator: "UCS",
        description: "תגובות עבור הדף " + site + "/" + path,
        id: domain + "/feed/" + site,
        link: domain,
        language: "he",
    });

    const comments = db.pageComments(site, path);

    for (const comment of comments) {
        feed.addItem({
            title: `New message by '${comment.user}' on ${path}`,
            description: comment.message,
            id: `${site}/${path}#comment-${comment.id}`,
            link: `${site}/${path}#comment-${comment.id}`,
            date: new Date(comment.published),
        });
    }

    var xml = feed.atom1();

    res.set("Content-Type", "text/xml");
    res.send(xml);
});
