/**
 * Utilities and constants.
 */
import RateLimit from "express-rate-limit";

import config from "./config.mjs";

// Constants

const domain = process.env.DOMAIN || config.domain || "localhost";

const port = process.env.PORT || config.port || 8080;

const db_path = process.env.DB || config.db_path || "ucs.db";

const cors = (function () {
    let origins = new Set();
    for (const site in config.sites) {
        config.sites[site].cors.forEach((origin) => {
            origins.add(origin);
        });
    }
    return Array.from(origins);
})();

// Functions

function escapeHtml(unsafe) {
    return unsafe
        .replace(/&/g, "&amp;")
        .replace(/</g, "&lt;")
        .replace(/>/g, "&gt;")
        .replace(/"/g, "&quot;")
        .replace(/'/g, "&#039;");
}

// Limiters

const limiter = (limit) =>
    RateLimit({
        windowMs: 1 * 60 * 1000,
        max: limit,
    });

export default {
    domain,
    port,
    db_path,
    cors,
    escapeHtml,
    get_limiter: limiter(config.limits_per_minute.get),
    post_limiter: limiter(config.limits_per_minute.post),
};
